@@ -1,5 +1,5 @@
 ;;; Guile-Avahi --- Guile bindings for Avahi.
-;;; Copyright (C) 2007  Ludovic Courts <ludo@gnu.org>
+;;; Copyright (C) 2007  Ludovic Courtès <ludo@gnu.org>
 ;;;
 ;;; This file is part of Guile-Avahi.
 ;;;
@@ -18,13 +18,17 @@
 
 (define-module (avahi test)
   :use-module (avahi)
-  :export (%service-type make-service-name make-host-name
+  :export (assert-exit
+           %service-type make-service-name make-host-name
            %timeout-sec iterate-simple-poll-until-true))
 
 ;;;
 ;;; Facilities for the test suite.
 ;;;
 
+(define (assert-exit x)
+  (primitive-exit (if x 0 1)))
+
 (define %service-type
   ;; The default service type used for testing.
   "_guile-avahi._tcp")
