@@ -1,5 +1,5 @@
 ;;; Guile-Avahi --- Guile bindings for Avahi.
-;;; Copyright (C) 2007  Ludovic Courts <ludo@gnu.org>
+;;; Copyright (C) 2007  Ludovic Courtès <ludo@gnu.org>
 ;;;
 ;;; This file is part of Guile-Avahi.
 ;;;
@@ -49,17 +49,17 @@
               (entry-group-state group)
 
               ;; not reached (normally)
-              (exit #f)))
+              (assert-exit #f)))
           (lambda (key err function . currently-unused)
             ;;(format #t "~a ~a ~a ~a~%"
             ;;        key err function currently-unused)
-            (exit (and (eq? key 'avahi-error)
+            (assert-exit (and (eq? key 'avahi-error)
                        (eq? err error/invalid-object)
                        (string? (error->string err))
                        (eq? function 'entry-group-state)))))))
 
     (lambda ()
       ;; failure
-      (exit 1)))
+      (assert-exit 1)))
 
 ;;; arch-tag: f5b90299-0cd8-4fae-8baf-27b456ceabcf
