@@ -1,5 +1,5 @@
 ;;; Guile-Avahi --- Guile bindings for Avahi.
-;;; Copyright (C) 2007  Ludovic Courts <ludo@gnu.org>
+;;; Copyright (C) 2007  Ludovic Courtès <ludo@gnu.org>
 ;;;
 ;;; This file is part of Guile-Avahi.
 ;;;
@@ -318,9 +318,9 @@
                                         1234 "scheme=yes" "java=no")
               (commit-entry-group group))))
 
-      (setvbuf (current-output-port) _IONBF)
+      (setvbuf (current-output-port) 'none)
 
-      (exit (let-values (((client iterate)
+      (assert-exit (let-values (((client iterate)
                           (make-avahi-client-event-loop %client-flags
                                                         client-callback)))
               (let loop ((seconds 0))
@@ -334,6 +334,6 @@
 
     (lambda ()
       ;; failure.
-      (exit 1)))
+      (assert-exit 1)))
 
 ;;; arch-tag: b7dc1451-607d-44ac-8d95-153eaef6a6a9
