@@ -1,5 +1,5 @@
 ;;; Guile-Avahi --- Guile bindings for Avahi.
-;;; Copyright (C) 2007  Ludovic Courts <ludo@gnu.org>
+;;; Copyright (C) 2007  Ludovic Courtès <ludo@gnu.org>
 ;;;
 ;;; This file is part of Guile-Avahi.
 ;;;
@@ -23,6 +23,7 @@
 
 (use-modules (avahi)
              (avahi client)
+             (avahi test)
              (srfi srfi-1))
 
 (dynamic-wind
@@ -35,7 +36,7 @@
                       (string? (client-state->string state))))
             (throw 'failure)))
 
-      (exit (and (simple-poll? (make-simple-poll))
+      (assert-exit (and (simple-poll? (make-simple-poll))
                  (every poll?
                         (let loop ((polls '())
                                    (count 123))
@@ -66,7 +67,7 @@
 
     (lambda ()
       ;; failure.
-      (exit 1)))
+      (assert-exit 1)))
 
 
 ;;; arch-tag: b866efb9-235f-4005-b9ca-8b246e0c8f80
